@@ -113,7 +113,7 @@ class TestCalendar(unittest.TestCase):
                        Date(2019, 5, 1), Date(2019, 5, 2), Date(2019, 5, 3),
                        Date(2019, 6, 7),
                        Date(2019, 9, 13),
-                       Date(2019, 9, 30), Date(2019, 10, 1), Date(2019, 10, 2), Date(2019, 10, 3), Date(2019, 10, 4)]
+                       Date(2019, 10, 1), Date(2019, 10, 2), Date(2019, 10, 3), Date(2019, 10, 4), Date(2019, 10, 5), Date(2019, 10, 6), Date(2019, 10, 7)]
 
         cal = Calendar('China.SSE')
 
